@@ -1,7 +1,15 @@
 with_mock_api({
-  test_that("ff_connect returns an S3 obj for each platform currently programmed", {
-    expect_s3_class(ff_connect("mfl", 54040), "mfl_conn")
-    expect_s3_class(ff_connect("sleeper", 527362181635997696), "sleeper_conn")
+  test_that("ff_connect returns an S3 platform_conn obj for each platform currently programmed", {
+    ssb <- ff_connect("mfl", 54040, user_agent = "ffscrapr_test")
+    jml <- ff_connect("sleeper", 527362181635997696)
+    solar <- ff_connect(
+      platform = "sleeper",
+      user_name = "solarpool"
+    )
+
+    expect_s3_class(ssb, "mfl_conn")
+    expect_s3_class(jml, "sleeper_conn")
+    expect_s3_class(solar, "sleeper_conn")
     expect_error(ff_connect("flea"))
   })
 
@@ -30,3 +38,8 @@ with_mock_api({
     expect_output(print(conn), "*MFL conn*")
   })
 })
+
+test_that("sleeper_connect edge cases are handled", {
+  expect_error(sleeper_connect(user_agent = c("pie", "cake")), regexp = "character vector of length one")
+  expect_error(sleeper_connect(user_agent = "ffscraprtest", rate_limit = 1), regexp = "rate_limit should be logical")
+})
