@@ -3,16 +3,16 @@ with_mock_api({
     sfb_conn <- ff_connect("mfl", 65443, season = 2020)
     sfb_draftresults <- ff_draft(sfb_conn)
 
-    expect_s3_class(sfb_draftresults, class = "tbl_df")
-    expect_gt(nrow(sfb_draftresults), 1)
+    expect_tibble(sfb_draftresults, min.rows = 100)
 
     ssb_conn <- ff_connect("mfl", 54040, season = 2020)
     ssb_draftresults <- ff_draft(ssb_conn)
 
-    expect_s3_class(ssb_draftresults, class = "tbl_df")
-    expect_gt(nrow(ssb_draftresults), 1)
+    expect_tibble(ssb_draftresults, min.rows = 40)
 
-    sleeper_conn <- ff_connect("sleeper", 527362181635997696, season = 2020)
-    expect_error(ff_draft(sleeper_conn))
+    jml_conn <- ff_connect(platform = "sleeper", league_id = '522458773317046272', season = 2020)
+    jml_draftresults <- ff_draft(jml_conn)
+
+    expect_tibble(jml_draftresults, min.rows = 40)
   })
 })
