@@ -7,7 +7,7 @@ test_that("choose season returns a character representation of a year", {
 
 with_mock_api({
   test_that(".fn_set_ratelimit creates a 'GET' function", {
-    expect_is(.fn_set_ratelimit(TRUE, 1, 1)$get("http://httpbin.org"), "response")
-    expect_is(.fn_set_ratelimit(FALSE)$get("http://httpbin.org"), "response")
+    expect_is(.fn_set_ratelimit(TRUE, 'MFL', 1, 1)$get("http://httpbin.org"), "response")
+    expect_is(.fn_set_ratelimit(FALSE, "MFL")$get("http://httpbin.org"), "response")
   })
 })
